Learn R Programming

stevethemes (version 0.1.0)

g_c: Get a Custom Color from steve_hex

Description

g_c() (i.e. *g*et *c*olor) is a simple function that interfaces with the steve_hex data frame to return a hex value associated with a named color.

Usage

g_c(x)

Value

g_c() returns a character vector, in particular, a hex triplet that coincides with the label supplied in the function. Use it for specifying a custom fill or color in a plot.

Arguments

x

a label coinciding with a value in the color column of the steve_hex data frame

Author

Steven V. Miller

Details

Check steve_hex in this same package for the custom colors included

Examples

Run this code

g_c("su_blue")

g_c("martel_pink")

Run the code above in your browser using DataLab